==> libgrinvin-core-java_1.0.4.orig.tar.gz: grinvin-core-1.0.4/org/grinvin/gred/mouse/AddVertices.java <==
/* AddVertices.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2007 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.gred.mouse;

import be.ugent.caagt.swirl.mouse.NullMouseHandler;

import java.awt.event.MouseEvent;
import javax.swing.JComponent;
import javax.swing.SwingUtilities;

import org.grinvin.gred.MutableGraphPanel;

/**
 * Mouse handler that adds a vertex at the given position. Consumes
 * all first button click events.
 */
public class AddVertices extends NullMouseHandler{
    
    // create a singleton
    private AddVertices() { }
    
    //
    private static AddVertices SINGLETON = new AddVertices();
    
    /**
     * Return the singleton object of this type.
     */
    public static AddVertices getHandler() {
        return SINGLETON;
    }
    
    /**
     * Adds a new vertex at the position clicked.
     */
    @Override public void doMouseClicked(JComponent parent, MouseEvent mouseEvent) {
        if (SwingUtilities.isLeftMouseButton(mouseEvent)) {
            MutableGraphPanel panel = (MutableGraphPanel)parent;
            panel.addNewVertex(mouseEvent.getX(), mouseEvent.getY(), null, true);
            mouseEvent.consume();
        }
    }
    
    /**
     * {@inheritDoc} This mouse handler needs a {@link MutableGraphPanel} 
     * as parent.
     */
    @Override public boolean canHandle(JComponent parent) {
        return parent instanceof MutableGraphPanel;
    }
}

==> libgrinvin-core-java_1.2.orig.tar.gz: grinvin-core-1.2/org/grinvin/gred/mouse/AddVertices.java <==
/* AddVertices.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.gred.mouse;

import be.ugent.caagt.swirl.mouse.NullMouseHandler;

import java.awt.event.MouseEvent;
import javax.swing.JComponent;
import javax.swing.SwingUtilities;

import org.grinvin.gred.MutableGraphPanel;

/**
 * Mouse handler that adds a vertex at the given position. Consumes
 * all first button click events.
 */
public class AddVertices extends NullMouseHandler{
    
    // create a singleton
    private AddVertices() { }
    
    //
    private static final AddVertices SINGLETON = new AddVertices();
    
    /**
     * Return the singleton object of this type.
     */
    public static AddVertices getHandler() {
        return SINGLETON;
    }
    
    /**
     * Adds a new vertex at the position clicked.
     */
    @Override public void doMouseClicked(JComponent parent, MouseEvent mouseEvent) {
        if (SwingUtilities.isLeftMouseButton(mouseEvent)) {
            MutableGraphPanel panel = (MutableGraphPanel)parent;
            panel.addNewVertex(mouseEvent.getX(), mouseEvent.getY(), null, true);
            mouseEvent.consume();
        }
    }
    
    /**
     * {@inheritDoc} This mouse handler needs a {@link MutableGraphPanel} 
     * as parent.
     */
    @Override public boolean canHandle(JComponent parent) {
        return parent instanceof MutableGraphPanel;
    }
}
